<?php

declare(strict_types=1);

namespace apexl\Io\modules\file\enums\permissions;

use app\module\newtonsTrailers\Enum\Permission\app\module\newtonsTrailers\Trait\IsPermissionTrait;
use app\module\newtonsTrailers\Interface\PermissionInterface;

enum File implements PermissionInterface, \JsonSerializable
{
    use IsPermissionTrait;
    
    case UPLOAD_FILES;
}
